#!/usr/bin/env python

# mythtv_import_evtest.py
# sample import script by mythrec (c)2017
# Licensed under GPL-3.0+ <http://spdx.org/licenses/GPL-3.0+>"

# This is for use with the MythTV Import Recorder and System Events
# Typically in conjunction with RecordingStarted and RecordingFinished events
# see https://www.mythtv.org/wiki/Import_recorder
# FIXME Update app path & log filename below as appropriate

# You should call this script in the Recording Started event e.g.
# mythtv_import_evtest.py -s %STARTTIMEUTC% -e %ENDTIMEUTC% -f %FILE% -c %CHANID% -t %CARDID%
# see https://www.mythtv.org/wiki/MythTV_System_Events

from MythTV import MythBE,MythDB,Channel
import sys
import os
import getopt
import datetime
import time

#Import a recording
def imp(card,chanid,st,et,file):
    mythtv = MythBE()
    #xml_id=Channel(chanid).xmltvid

    retry=0
    while True:
        #this is not necessarily the prog we want to start recording
        #i.e. could still be on the previous show if they are back to back
        prog=mythtv.getCurrentRecording(card)
        if prog and prog.filename and file in prog.filename:
            fp=prog.filename
            break
        retry+=1
        if retry>1:
            raise RuntimeError('timeout when waiting for import path')
        time.sleep(30)

    sd=(et - st).total_seconds()
    f.write("Starting import %s\n"%(fp))
    app='(mythtv_import.sh "%s" %d &)' % (fp,sd) #FIXME Update app path
    f.write("%s\n"%(app))
    os.system(app)

#Check command line options
def parseCliOpts(argc,argv):
    opts,args = getopt.getopt(argv[1:],'s:e:f:c:t:')
    for (opt,arg) in opts:
        if opt == '-s':
            start=datetime.datetime.strptime(arg,"%Y%m%d%H%M%S")
        elif opt == '-e':
            end=datetime.datetime.strptime(arg,"%Y%m%d%H%M%S")
        elif opt == '-f':
            file=arg
        elif opt == '-c':
            chan=int(arg)
        elif opt == '-t':
            card=int(arg)
            
    mythdb = MythDB()    
    with mythdb as cursor:     
        cursor.execute("""SELECT cardtype from capturecard WHERE cardid=%s""",(card,))    
        row = cursor.fetchone()     
        if row is None:
            raise ValueError('unknown card number',card)
        ct=row[0]    
                
    if (ct=="IMPORT"):
        imp(card,chan,start,end,file)

#Main
def main(argc,argv):
    parseCliOpts(argc,argv)

if __name__ == "__main__":
    f=open('/home/mythtv/import.log','a') #FIXME Update as appropriate
    try:
        f.write("=======IMP-START:%s=======\n"%(datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S")))
        f.write(" ".join(sys.argv[:]))
        f.write("\n")
        main(len(sys.argv),sys.argv)
        f.write("=======IMP-END:%s=======\n"%(datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S")))
        f.close()
    except Exception, e:
        print 'Caught main exception:',e
        f.write("IMP-ERR: Exception %s\n"%(e))
        sys.exit(1)
